# PackageMetadata

[Package metadata](#metadata-model) that has been extracted from the uploaded package. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | Name of the Compute package. | [optional] 
**description** | **str** | Description of the Compute package. | [optional] 
**authors** | **[str]** | A list of package authors&#39; email addresses. | [optional] 
**language** | **str** | The language of the Compute package. | [optional] 
**size** | **int** | Size of the Compute package in bytes. | [optional] 
**hashsum** | **str** | Hash of the Compute package. | [optional] 
**files_hash** | **str** | Hash of the files within the Compute package. | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


